[orca/570658-whereami] Rename the "get" methods of the speech generator to "generate" methods



commit 5586983ae0603ffd16872ea5b4e8f8bd658cf07a
Author: Willie Walker <william walker sun com>
Date:   Fri Jun 5 21:20:47 2009 -0400

    Rename the "get" methods of the speech generator to "generate" methods
---
 src/orca/bookmarks.py                              |    2 +-
 src/orca/default.py                                |   21 +-
 src/orca/mouse_review.py                           |    4 +-
 .../scripts/apps/Thunderbird/speech_generator.py   |    6 +-
 src/orca/scripts/apps/acroread.py                  |    6 +-
 src/orca/scripts/apps/evolution/script.py          |   18 +-
 .../scripts/apps/evolution/speech_generator.py     |   10 +-
 .../scripts/apps/gcalctool/speech_generator.py     |   10 +-
 src/orca/scripts/apps/gedit/script.py              |    2 +-
 src/orca/scripts/apps/gnome-panel.py               |    2 +-
 src/orca/scripts/apps/gnome-terminal.py            |    2 +-
 src/orca/scripts/apps/liferea.py                   |    2 +-
 src/orca/scripts/apps/pidgin/speech_generator.py   |   20 +-
 src/orca/scripts/apps/planner/speech_generator.py  |    7 +-
 .../scripts/apps/rhythmbox/speech_generator.py     |    6 +-
 src/orca/scripts/apps/soffice/script.py            |   12 +-
 src/orca/scripts/apps/soffice/speech_generator.py  |   50 ++--
 src/orca/scripts/apps/yelp.py                      |    2 +-
 src/orca/scripts/toolkits/Gecko/bookmarks.py       |    2 +-
 src/orca/scripts/toolkits/Gecko/script.py          |   10 +-
 .../scripts/toolkits/Gecko/speech_generator.py     |   59 +++--
 .../J2SE-access-bridge/speech_generator.py         |    6 +-
 src/orca/speech_generator.py                       |  259 ++++++++++----------
 src/orca/structural_navigation.py                  |    2 +-
 src/orca/where_am_I.py                             |   11 +-
 25 files changed, 271 insertions(+), 260 deletions(-)

diff --git a/src/orca/bookmarks.py b/src/orca/bookmarks.py
index 7a86bec..2f6bcd1 100644
--- a/src/orca/bookmarks.py
+++ b/src/orca/bookmarks.py
@@ -78,7 +78,7 @@ class Bookmarks:
         #
         utterances = [_('bookmark entered')]
         utterances.extend(
-            self._script.speechGenerator.getSpeech(
+            self._script.speechGenerator.generateSpeech(
                 context.getCurrentAccessible()))
         speech.speak(utterances)
 
diff --git a/src/orca/default.py b/src/orca/default.py
index 17262d8..76a9574 100644
--- a/src/orca/default.py
+++ b/src/orca/default.py
@@ -2054,7 +2054,7 @@ class Script(script.Script):
             try:
                 orca_state.locusOfFocus.queryText()
             except NotImplementedError:
-                utterances = self.speechGenerator.getSpeech(
+                utterances = self.speechGenerator.generateSpeech(
                     orca_state.locusOfFocus)
                 utterances.extend(self.tutorialGenerator.getTutorial(
                            orca_state.locusOfFocus, False))
@@ -2566,7 +2566,7 @@ class Script(script.Script):
 
         obj = orca_state.locusOfFocus
         self.updateBraille(obj)
-        speech.speak(self.speechGenerator.getTitle(obj))
+        speech.speak(self.speechGenerator.generateTitle(obj))
 
     def presentStatusBar(self, inputEvent):
         """Speaks and brailles the contents of the status bar and/or default
@@ -2584,10 +2584,10 @@ class Script(script.Script):
             # speak the status bar info immediately and then go looking
             # for a default button.
             #
-            speech.speak(self.speechGenerator.getStatusBar(frame))
+            speech.speak(self.speechGenerator.generateStatusBar(frame))
         window = dialog or frame
         if window:
-            speech.speak(self.speechGenerator.getDefaultButton(window))
+            speech.speak(self.speechGenerator.generateDefaultButton(window))
 
     def findStatusBar(self, obj):
         """Returns the status bar in the window which contains obj.
@@ -2922,7 +2922,7 @@ class Script(script.Script):
             else:
                 voice = self.voices[settings.DEFAULT_VOICE]
 
-            utterances = self.speechGenerator.getSpeech(
+            utterances = self.speechGenerator.generateSpeech(
                 newLocusOfFocus,
                 priorObj=oldLocusOfFocus)
             speech.speak(utterances, voice, not shouldNotInterrupt)
@@ -3031,7 +3031,7 @@ class Script(script.Script):
                 target = relation.getTarget(0)
                 if target == orca_state.locusOfFocus:
                     self.updateBraille(target)
-                    utterances = self.speechGenerator.getSpeech(
+                    utterances = self.speechGenerator.generateSpeech(
                         target, alreadyFocused=True)
                     utterances.extend(self.tutorialGenerator.getTutorial(
                                target, True))
@@ -3050,7 +3050,7 @@ class Script(script.Script):
                     target = relation.getTarget(0)
                     if target == orca_state.locusOfFocus:
                         self.updateBraille(target)
-                        utterances = self.speechGenerator.getSpeech(
+                        utterances = self.speechGenerator.generateSpeech(
                             target, alreadyFocused=True)
                         utterances.extend(self.tutorialGenerator.getTutorial(
                                           target, True))
@@ -3085,7 +3085,8 @@ class Script(script.Script):
 
         mag.magnifyAccessible(event, obj)
         self.updateBraille(obj)
-        utterances = self.speechGenerator.getSpeech(obj, alreadyFocused=True)
+        utterances = self.speechGenerator.generateSpeech(
+                         obj, alreadyFocused=True)
         utterances.extend(self.tutorialGenerator.getTutorial(obj, True))
         speech.speak(utterances)
 
@@ -3858,7 +3859,7 @@ class Script(script.Script):
                     and (orca_state.lastNonModifierKeyEvent.event_string \
                          == "F1"):
                     self.updateBraille(orca_state.locusOfFocus)
-                    utterances = self.speechGenerator.getSpeech(
+                    utterances = self.speechGenerator.generateSpeech(
                         orca_state.locusOfFocus)
                     utterances.extend(self.tutorialGenerator.getTutorial(
                                       orca_state.locusOfFocus, False))
@@ -5255,7 +5256,7 @@ class Script(script.Script):
         # the Braille display as an input device.
         #
         if not isinstance(inputEvent, input_event.BrailleEvent):
-            utterances = self.speechGenerator.getSpeech(
+            utterances = self.speechGenerator.generateSpeech(
                     context.getCurrentAccessible())
             utterances.extend(self.tutorialGenerator.getTutorial(
                     context.getCurrentAccessible(), False))
diff --git a/src/orca/mouse_review.py b/src/orca/mouse_review.py
index 45ac68a..fd98062 100644
--- a/src/orca/mouse_review.py
+++ b/src/orca/mouse_review.py
@@ -266,8 +266,8 @@ class MouseReviewer:
                 braille.displayMessage(obj)
             else:
                 speech.speak(
-                    self._currentMouseOver.script.speechGenerator.getSpeech(
-                        obj))
+                    self._currentMouseOver.script.speechGenerator.\
+                        generateSpeech(obj))
                 self._currentMouseOver.script.updateBraille(obj)
 
     def _getZOrder(self, frame_name):
diff --git a/src/orca/scripts/apps/Thunderbird/speech_generator.py b/src/orca/scripts/apps/Thunderbird/speech_generator.py
index dc13506..dfbaf86 100644
--- a/src/orca/scripts/apps/Thunderbird/speech_generator.py
+++ b/src/orca/scripts/apps/Thunderbird/speech_generator.py
@@ -47,7 +47,7 @@ class SpeechGenerator(Gecko.SpeechGenerator):
     def __init__(self, script):
         Gecko.SpeechGenerator.__init__(self, script)
 
-    def _getColumnHeader(self, obj, **args):
+    def _generateColumnHeader(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the column header for an object
         that is in a table, if it exists.  Otherwise, an empty array
@@ -60,7 +60,7 @@ class SpeechGenerator(Gecko.SpeechGenerator):
         #
         return result
 
-    def _getUnrelatedLabels(self, obj, **args):
+    def _generateUnrelatedLabels(self, obj, **args):
         """Finds all labels not in a label for or labelled by relation.
         If this is the spell checking dialog, then there are no
         unrelated labels.  See bug #535192 for more details.
@@ -78,6 +78,6 @@ class SpeechGenerator(Gecko.SpeechGenerator):
                          pyatspi.ROLE_APPLICATION]):
             pass
         else:
-            result.extend(Gecko.SpeechGenerator._getUnrelatedLabels(
+            result.extend(Gecko.SpeechGenerator._generateUnrelatedLabels(
                               self, obj, **args))
         return result
diff --git a/src/orca/scripts/apps/acroread.py b/src/orca/scripts/apps/acroread.py
index 992ce10..b043f13 100644
--- a/src/orca/scripts/apps/acroread.py
+++ b/src/orca/scripts/apps/acroread.py
@@ -438,7 +438,7 @@ class Script(default.Script):
                 return
 
             utterances = \
-                 self.speechGenerator.getSpeech(newLocusOfFocus)
+                 self.speechGenerator.generateSpeech(newLocusOfFocus)
             speech.speak(utterances)
             brailleRegions = \
                  self.brailleGenerator.getBrailleRegions(newLocusOfFocus)
@@ -469,7 +469,7 @@ class Script(default.Script):
             # verboseness: reporting the drawing area(s) in which this link
             # is contained, speaking the periods in a table of contents, etc.
             #
-            utterances = self.speechGenerator.getSpeech(newLocusOfFocus)
+            utterances = self.speechGenerator.generateSpeech(newLocusOfFocus)
             adjustedUtterances = []
             for utterance in utterances:
                 adjustedUtterances.append(self.adjustForRepeats(utterance))
@@ -554,7 +554,7 @@ class Script(default.Script):
                 # Try to minimize chattiness in the Search panel
                 #
                 utterances = \
-                     self.speechGenerator.getSpeech(event.source)
+                     self.speechGenerator.generateSpeech(event.source)
                 speech.speak(utterances)
                 brailleRegions = \
                      self.brailleGenerator.getBrailleRegions(event.source)
diff --git a/src/orca/scripts/apps/evolution/script.py b/src/orca/scripts/apps/evolution/script.py
index d39802d..9b77cd2 100644
--- a/src/orca/scripts/apps/evolution/script.py
+++ b/src/orca/scripts/apps/evolution/script.py
@@ -289,7 +289,7 @@ class Script(default.Script):
                                        pyatspi.STATE_SENSITIVE)):
                                     self.updateBraille(orca_state.locusOfFocus)
                                     speech.speak(
-                                        self.speechGenerator.getSpeech(
+                                        self.speechGenerator.generateSpeech(
                                             orca_state.locusOfFocus))
             except NotImplementedError:
                 pass
@@ -342,7 +342,7 @@ class Script(default.Script):
 
         savedSpeechVerbosityLevel = settings.speechVerbosityLevel
         settings.speechVerbosityLevel = settings.VERBOSITY_LEVEL_BRIEF
-        utterances = speechGen.getSpeech(tab)
+        utterances = speechGen.generateSpeech(tab)
         speech.speak(utterances)
         settings.speechVerbosityLevel = savedSpeechVerbosityLevel
 
@@ -1090,7 +1090,7 @@ class Script(default.Script):
                             settings.speechVerbosityLevel = \
                                 settings.VERBOSITY_LEVEL_BRIEF
 
-                            utterances = speechGen.getSpeech(
+                            utterances = speechGen.generateSpeech(
                                 header,
                                 includeContext=False,
                                 priorObj=oldLocusOfFocus)
@@ -1119,7 +1119,7 @@ class Script(default.Script):
                                 settings.VERBOSITY_LEVEL_BRIEF
                         settings.speechVerbosityLevel = \
                             savedSpeechVerbosityLevel
-                        utterances = speechGen.getSpeech(
+                        utterances = speechGen.generateSpeech(
                             cell,
                             includeContext=False,
                             priorObj=oldLocusOfFocus)
@@ -1213,9 +1213,9 @@ class Script(default.Script):
                           + "day view: tabbing to day with appts.")
 
             parent = event.source.parent
-            utterances = speechGen.getSpeech(parent,
-                                             includeContext=False,
-                                             priorObj=oldLocusOfFocus)
+            utterances = speechGen.generateSpeech(parent,
+                                                  includeContext=False,
+                                                  priorObj=oldLocusOfFocus)
             [brailleRegions, focusedRegion] = \
                     brailleGen.getBrailleRegions(parent)
             speech.speak(utterances)
@@ -1231,7 +1231,7 @@ class Script(default.Script):
                         appt = childTable.getAccessibleAt(row, 0)
                         extents = appt.queryComponent().getExtents(0)
                         if extents.y == apptExtents.y:
-                            utterances = speechGen.getSpeech(
+                            utterances = speechGen.generateSpeech(
                                 event.source,
                                 includeContext=False,
                                 priorObj=oldLocusOfFocus)
@@ -1295,7 +1295,7 @@ class Script(default.Script):
                     apptExtents = child.queryComponent().getExtents(0)
 
                     if extents.y == apptExtents.y:
-                        utterances = speechGen.getSpeech(
+                        utterances = speechGen.generateSpeech(
                             child,
                             includeContext=False,
                             priorObj=oldLocusOfFocus)
diff --git a/src/orca/scripts/apps/gedit/script.py b/src/orca/scripts/apps/gedit/script.py
index 091957d..aff35e7 100644
--- a/src/orca/scripts/apps/gedit/script.py
+++ b/src/orca/scripts/apps/gedit/script.py
@@ -570,7 +570,7 @@ class Script(default.Script):
                 # finding something.
                 #
                 speech.speak(_("Phrase found."))
-                utterances = self.speechGenerator.getSpeech(
+                utterances = self.speechGenerator.generateSpeech(
                     event.source, alreadyFocused=True)
                 speech.speak(utterances)
 
diff --git a/src/orca/scripts/apps/gnome-panel.py b/src/orca/scripts/apps/gnome-panel.py
index 0a1fc4a..f1528b1 100644
--- a/src/orca/scripts/apps/gnome-panel.py
+++ b/src/orca/scripts/apps/gnome-panel.py
@@ -88,7 +88,7 @@ class Script(default.Script):
             if event.type.startswith("object:state-changed:showing") and \
                event.detail1 == 1:
                 braille.displayMessage(obj.name)
-                utterances = self.speechGenerator.getSpeech(obj)
+                utterances = self.speechGenerator.generateSpeech(obj)
                 speech.speak(utterances)
 
         # If focus moves to something within a panel and focus was not
diff --git a/src/orca/scripts/apps/gnome-terminal.py b/src/orca/scripts/apps/gnome-terminal.py
index 8b905d0..655641f 100644
--- a/src/orca/scripts/apps/gnome-terminal.py
+++ b/src/orca/scripts/apps/gnome-terminal.py
@@ -100,7 +100,7 @@ class Script(default.Script):
                pageTab.getRole() == pyatspi.ROLE_PAGE_TAB and \
                pageTab.getState().contains(pyatspi.STATE_SENSITIVE):
                 self.updateBraille(newLocusOfFocus)
-                utterances = self.speechGenerator.getSpeech(pageTab)
+                utterances = self.speechGenerator.generateSpeech(pageTab)
                 speech.speak(utterances)
 
         default.Script.locusOfFocusChanged(self, event, 
diff --git a/src/orca/scripts/apps/liferea.py b/src/orca/scripts/apps/liferea.py
index 32a0a05..cd70f39 100644
--- a/src/orca/scripts/apps/liferea.py
+++ b/src/orca/scripts/apps/liferea.py
@@ -119,7 +119,7 @@ class Script(default.Script):
             # Here we extend the utterances with the speech generator for 
             # the object with focus (the push button).
             #
-            utterances.extend(speechGen.getSpeech(event.source))
+            utterances.extend(speechGen.generateSpeech(event.source))
 
             # Finally we speak/braille the utterances/regions.
             #
diff --git a/src/orca/scripts/apps/pidgin/speech_generator.py b/src/orca/scripts/apps/pidgin/speech_generator.py
index 6c91709..6d526dc 100644
--- a/src/orca/scripts/apps/pidgin/speech_generator.py
+++ b/src/orca/scripts/apps/pidgin/speech_generator.py
@@ -20,7 +20,7 @@
 __id__        = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
-__copyright__ = "Copyright (c) 2005-2009 Sun Microsystems Inc."
+__copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import orca.speech_generator as speech_generator
@@ -32,7 +32,7 @@ import orca.speech_generator as speech_generator
 ########################################################################
 
 class SpeechGenerator(speech_generator.SpeechGenerator):
-    """Overrides _getSpeechForTableCell() so that we can provide access
+    """Overrides _generateExpandableState so that we can provide access
     to the expanded/collapsed state and node count for the buddy list.
     """
 
@@ -41,7 +41,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
     def __init__(self, script):
         speech_generator.SpeechGenerator.__init__(self, script)
 
-    def _getExpandableState(self, obj, **args):
+    def _generateExpandableState(self, obj, **args):
         result = []
         if self._script.isInBuddyList(obj):
             # The Pidgin buddy list consists of two columns. The
@@ -54,19 +54,19 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             expanderCell = obj.parent[obj.getIndexInParent() - 1]
             if expanderCell:
                 result.extend(
-                    speech_generator.SpeechGenerator._getExpandableState(
+                    speech_generator.SpeechGenerator._generateExpandableState(
                         self, expanderCell, **args))
             else:
                 result.extend(
-                    speech_generator.SpeechGenerator._getExpandableState(
+                    speech_generator.SpeechGenerator._generateExpandableState(
                         self, obj, **args))
         else:
             result.extend(
-                speech_generator.SpeechGenerator._getExpandableState(
+                speech_generator.SpeechGenerator._generateExpandableState(
                     self, obj, **args))
         return result
 
-    def _getNumberOfChildren(self, obj, **args):
+    def _generateNumberOfChildren(self, obj, **args):
         result = []
         if self._script.isInBuddyList(obj):
             # The Pidgin buddy list consists of two columns. The
@@ -79,14 +79,14 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             expanderCell = obj.parent[obj.getIndexInParent() - 1]
             if expanderCell:
                 result.extend(
-                    speech_generator.SpeechGenerator._getNumberOfChildren(
+                    speech_generator.SpeechGenerator._generateNumberOfChildren(
                         self, expanderCell, **args))
             else:
                 result.extend(
-                    speech_generator.SpeechGenerator._getNumberOfChildren(
+                    speech_generator.SpeechGenerator._generateNumberOfChildren(
                         self, obj, **args))
         else:
             result.extend(
-                speech_generator.SpeechGenerator._getNumberOfChildren(
+                speech_generator.SpeechGenerator._generateNumberOfChildren(
                     self, obj, **args))
         return result
diff --git a/src/orca/scripts/apps/planner/speech_generator.py b/src/orca/scripts/apps/planner/speech_generator.py
index 0f31c6a..0931c44 100644
--- a/src/orca/scripts/apps/planner/speech_generator.py
+++ b/src/orca/scripts/apps/planner/speech_generator.py
@@ -38,7 +38,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
     def __init__(self, script):
         speech_generator.SpeechGenerator.__init__(self, script)
 
-    def _getLabelAndName(self, obj, **args):
+    def _generateLabelAndName(self, obj, **args):
         """Gets the label and the name if the name is different from the label.
         """
         result = []
@@ -64,7 +64,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         elif handleTabButton:
             result.append(self._script.getDisplayedText(obj.parent[1]))
         else:
-            result.append(speech_generator.SpeechGenerator._getLabelAndName(
-                self, obj, **args))
+            result.append(
+                speech_generator.SpeechGenerator._generateLabelAndName(
+                    self, obj, **args))
 
         return result
diff --git a/src/orca/scripts/apps/soffice/speech_generator.py b/src/orca/scripts/apps/soffice/speech_generator.py
index 1792bb5..274bf13 100644
--- a/src/orca/scripts/apps/soffice/speech_generator.py
+++ b/src/orca/scripts/apps/soffice/speech_generator.py
@@ -54,7 +54,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                                              [pyatspi.ROLE_APPLICATION]))
         return override
 
-    def _getRoleName(self, obj, **args):
+    def _generateRoleName(self, obj, **args):
         result = []
         role = args.get('role', obj.getRole())
         if role in [pyatspi.ROLE_PUSH_BUTTON, pyatspi.ROLE_TOGGLE_BUTTON] \
@@ -69,21 +69,21 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             override = self.__overrideParagraph(obj, **args)
             if override:
                 oldRole = self._overrideRole(pyatspi.ROLE_TEXT, args)
-            result.extend(speech_generator.SpeechGenerator._getRoleName(
+            result.extend(speech_generator.SpeechGenerator._generateRoleName(
                           self, obj, **args))
             if override:
                 self._restoreRole(oldRole, args)
         return result
 
-    def _getTextRole(self, obj, **args):
+    def _generateTextRole(self, obj, **args):
         result = []
         role = args.get('role', obj.getRole())
         if role != pyatspi.ROLE_PARAGRAPH \
            or self.__overrideParagraph(obj, **args):
-            result.extend(self._getRoleName(obj, **args))
+            result.extend(self._generateRoleName(obj, **args))
         return result
 
-    def _getLabelOrName(self, obj, **args):
+    def _generateLabelOrName(self, obj, **args):
         """Gets the label or the name if the label is not preset."""
         result = []
         override = self.__overrideParagraph(obj, **args)
@@ -91,9 +91,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         # as a text object.
         #
         if override:
-            result.extend(self._getLabel(obj, **args))
+            result.extend(self._generateLabel(obj, **args))
             if len(result) == 0 and obj.parent:
-                parentLabel = self._getLabel(obj.parent, **args)
+                parentLabel = self._generateLabel(obj.parent, **args)
                 # If we aren't already focused, we will have spoken the
                 # parent as part of the speech context and do not want
                 # to repeat it.
@@ -106,11 +106,11 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 if not parentLabel and obj.name and len(obj.name):
                     result.append(obj.name)
         else:
-            result.extend(speech_generator.SpeechGenerator._getLabelOrName(
+            result.extend(speech_generator.SpeechGenerator._generateLabelOrName(
                 self, obj, **args))
         return result
 
-    def _getToggleState(self, obj, **args):
+    def _generateToggleState(self, obj, **args):
         """Treat push buttons (which act like toggle buttons) and toggle
         buttons in the toolbar specially.  This is so we can have more
         natural sounding speech such as "bold on", "bold off", etc."""
@@ -127,11 +127,11 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 #
                 result.append(_("off"))
         elif role == pyatspi.ROLE_TOGGLE_BUTTON:
-            result.extend(speech_generator.SpeechGenerator._getToggleState(
+            result.extend(speech_generator.SpeechGenerator._generateToggleState(
                 self, obj, **args))
         return result
 
-    def _getNewRowHeader(self, obj, **args):
+    def _generateNewRowHeader(self, obj, **args):
         result = []
         # Check to see if this spread sheet cell has either a dynamic
         # row heading associated with it.
@@ -164,7 +164,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                         result.append(text)
         return result
 
-    def _getNewColumnHeader(self, obj, **args):
+    def _generateNewColumnHeader(self, obj, **args):
         result = []
         # Check to see if this spread sheet cell has either a dynamic
         # row heading associated with it.
@@ -197,7 +197,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                         result.append(text)
         return result
 
-    def _getSpreadSheetCell(self, obj, **args):
+    def _generateSpreadSheetCell(self, obj, **args):
         result = []
         if self._script.inputLineForCell == None:
             self._script.inputLineForCell = \
@@ -223,13 +223,13 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             # examine each item and choose the one which contains a
             # digit.
             #
-            for name in nameList:                    
+            for name in nameList:
                 for char in name.decode("UTF-8"):
                     if char.isdigit():
                         result.append(name)
         return result
 
-    def _getRealTableCell(self, obj, **args):
+    def _generateRealTableCell(self, obj, **args):
         """Get the speech for a table cell. If this isn't inside a
         spread sheet, just return the utterances returned by the default
         table cell speech handler.
@@ -241,7 +241,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         """
         result = []
         if self._script.isSpreadSheetCell(obj):
-            result.extend(self._getSpreadSheetCell(obj, **args))
+            result.extend(self._generateSpreadSheetCell(obj, **args))
         else:
             # Check to see how many children this table cell has. If it's
             # just one (or none), then pass it on to the superclass to be
@@ -252,13 +252,13 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             #
             if obj.childCount <= 1:
                 result.extend(speech_generator.SpeechGenerator.\
-                              _getRealTableCell(self, obj, **args))
+                              _generateRealTableCell(self, obj, **args))
             else:
                 for child in obj:
-                    result.extend(self._getRealTableCell(child, **args))
+                    result.extend(self._generateRealTableCell(child, **args))
         return result
 
-    def _getTableCellRow(self, obj, **args):
+    def _generateTableCellRow(self, obj, **args):
         """Get the speech for a table cell row or a single table cell
         if settings.readTableCellRow is False. If this isn't inside a
         spread sheet, just return the utterances returned by the default
@@ -297,12 +297,14 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                         showing = cell.getState().contains( \
                                       pyatspi.STATE_SHOWING)
                         if showing:
-                            result.extend(self._getRealTableCell(cell, **args))
+                            result.extend(self._generateRealTableCell(
+                                              cell, **args))
                 else:
-                    result.extend(self._getRealTableCell(obj, **args))
+                    result.extend(self._generateRealTableCell(obj, **args))
             else:
-                result.extend(self._getRealTableCell(obj, **args))
+                result.extend(self._generateRealTableCell(obj, **args))
         else:
-            result.extend(speech_generator.SpeechGenerator._getTableCellRow(
-                          self, obj, **args))
+            result.extend(
+                speech_generator.SpeechGenerator._generateTableCellRow(
+                    self, obj, **args))
         return result
diff --git a/src/orca/scripts/apps/yelp.py b/src/orca/scripts/apps/yelp.py
index d5ef25a..77a1f85 100644
--- a/src/orca/scripts/apps/yelp.py
+++ b/src/orca/scripts/apps/yelp.py
@@ -204,7 +204,7 @@ class Script(Gecko.Script):
                 self._currentFrameName = event.source.name
                 self.setCaretPosition(obj, characterOffset)
                 if obj.getState().contains(pyatspi.STATE_FOCUSED):
-                    speech.speak(self.speechGenerator.getSpeech(obj))
+                    speech.speak(self.speechGenerator.generateSpeech(obj))
                 elif not Gecko.script_settings.sayAllOnLoad:
                     self.speakContents(\
                         self.getLineContentsAtOffset(obj, characterOffset))
diff --git a/src/orca/scripts/toolkits/Gecko/bookmarks.py b/src/orca/scripts/toolkits/Gecko/bookmarks.py
index 5f97392..275b054 100644
--- a/src/orca/scripts/toolkits/Gecko/bookmarks.py
+++ b/src/orca/scripts/toolkits/Gecko/bookmarks.py
@@ -60,7 +60,7 @@ class GeckoBookmarks(bookmarks.Bookmarks):
         # Translators: this announces that a bookmark has been entered
         #
         utterances = [(_('entered bookmark'))]
-        utterances.extend(self._script.speechGenerator.getSpeech \
+        utterances.extend(self._script.speechGenerator.generateSpeech \
                          (obj, False))
         speech.speak(utterances)
         
diff --git a/src/orca/scripts/toolkits/Gecko/script.py b/src/orca/scripts/toolkits/Gecko/script.py
index c4ecb49..65b2f9b 100644
--- a/src/orca/scripts/toolkits/Gecko/script.py
+++ b/src/orca/scripts/toolkits/Gecko/script.py
@@ -1559,7 +1559,7 @@ class Script(default.Script):
             if settings.speechVerbosityLevel == \
                     settings.VERBOSITY_LEVEL_VERBOSE:
                 utterances.extend(
-                    self.speechGenerator.getSpeech(event.any_data))
+                    self.speechGenerator.generateSpeech(event.any_data))
             speech.speak(utterances)
 
     def onDocumentReload(self, event):
@@ -1692,7 +1692,7 @@ class Script(default.Script):
                     # http://bugzilla.gnome.org/show_bug.cgi?id=570551
                     #
                     if eventSourceRole == pyatspi.ROLE_ALERT:
-                        speech.speak(self.speechGenerator.getSpeech(
+                        speech.speak(self.speechGenerator.generateSpeech(
                                 event.source))
                         self.updateBraille(obj)
                     else:
@@ -1882,7 +1882,7 @@ class Script(default.Script):
                     self.updateBraille(obj)
 
                     if obj.getState().contains(pyatspi.STATE_FOCUSABLE):
-                        speech.speak(self.speechGenerator.getSpeech(obj))
+                        speech.speak(self.speechGenerator.generateSpeech(obj))
                     elif not script_settings.sayAllOnLoad:
                         self.speakContents(\
                             self.getLineContentsAtOffset(obj,
@@ -5436,7 +5436,7 @@ class Script(default.Script):
             #
             if not len(string) \
                or role in [pyatspi.ROLE_ENTRY, pyatspi.ROLE_PASSWORD_TEXT]:
-                utterance = self.speechGenerator.getSpeech(obj)
+                utterance = self.speechGenerator.generateSpeech(obj)
             else:
                 utterance = [string]
                 if speakRole and not role in doNotSpeakRoles:
@@ -5522,7 +5522,7 @@ class Script(default.Script):
                 # characterOffset (lists).  In these latter cases, we'll just
                 # speak the entire component.
                 #
-                utterances = self.speechGenerator.getSpeech(obj)
+                utterances = self.speechGenerator.generateSpeech(obj)
                 speech.speak(utterances)
 
     ####################################################################
diff --git a/src/orca/scripts/toolkits/Gecko/speech_generator.py b/src/orca/scripts/toolkits/Gecko/speech_generator.py
index 5ac571b..a755969 100644
--- a/src/orca/scripts/toolkits/Gecko/speech_generator.py
+++ b/src/orca/scripts/toolkits/Gecko/speech_generator.py
@@ -52,7 +52,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
     def __init__(self, script):
         speech_generator.SpeechGenerator.__init__(self, script)
 
-    def _getName(self, obj, **args):
+    def _generateName(self, obj, **args):
         result = []
         role = args.get('role', obj.getRole())
         if role == pyatspi.ROLE_COMBO_BOX:
@@ -74,9 +74,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                     if not child:
                         # It's probably a Gtk combo box.
                         #
-                        result = \
-                            speech_generator.SpeechGenerator._getDisplayedText(
-                                self, obj, **args)
+                        result = speech_generator.SpeechGenerator.\
+                            _generateDisplayedText(self, obj, **args)
                 except:
                     # But just in case, we'll fall back on this.
                     # [[[TODO - JD: Will we ever have a case where the first
@@ -89,9 +88,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 if child and child.name:
                     result.append(child.name)
         else:
-            result.extend(speech_generator.SpeechGenerator._getName(self,
-                                                                    obj,
-                                                                    **args))
+            result.extend(speech_generator.SpeechGenerator._generateName(
+                              self, obj, **args))
         if not result and role == pyatspi.ROLE_LIST_ITEM:
             result.append(self._script.expandEOCs(obj))
 
@@ -112,8 +110,10 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         return result
 
-    def _getLabel(self, obj, **args):
-        result = speech_generator.SpeechGenerator._getLabel(self, obj, **args)
+    def _generateLabel(self, obj, **args):
+        result = speech_generator.SpeechGenerator._generateLabel(self,
+                                                                 obj,
+                                                                 **args)
         role = args.get('role', obj.getRole())
         # We'll attempt to guess the label under some circumstances.
         #
@@ -143,7 +143,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         return result
 
-    def _getLabelAndName(self, obj, **args):
+    def _generateLabelAndName(self, obj, **args):
         result = []
         role = args.get('role', obj.getRole())
         # For radio buttons, the label is handled as a context and we
@@ -154,24 +154,25 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
            and self._script.getDisplayedLabel(obj):
             pass
         else:
-            result.extend(speech_generator.SpeechGenerator._getLabelAndName(
-                self, obj, **args))
+            result.extend(
+                speech_generator.SpeechGenerator._generateLabelAndName(
+                    self, obj, **args))
         return result
 
-    def _getLabelOrName(self, obj, **args):
+    def _generateLabelOrName(self, obj, **args):
         result = []
         if obj.parent.getRole() == pyatspi.ROLE_AUTOCOMPLETE:
             # This is the main difference between this class and the default
             # class - we'll give this thing a name here, and we'll make it
             # be the name of the autocomplete.
             #
-            result.extend(self._getLabelOrName(obj.parent, **args))
+            result.extend(self._generateLabelOrName(obj.parent, **args))
         else:
-            result.extend(speech_generator.SpeechGenerator._getLabelOrName(
+            result.extend(speech_generator.SpeechGenerator._generateLabelOrName(
                 self, obj, **args))
         return result
 
-    def _getRoleName(self, obj, **args):
+    def _generateRoleName(self, obj, **args):
         """Prevents some roles from being spoken."""
         result = []
         role = args.get('role', obj.getRole())
@@ -187,7 +188,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                                                 [pyatspi.ROLE_COMBO_BOX],
                                                 [pyatspi.ROLE_DOCUMENT_FRAME])
             if comboBox:
-                return self._getRoleName(comboBox, **args)
+                return self._generateRoleName(comboBox, **args)
 
         if not force:
             doNotSpeak = [pyatspi.ROLE_FORM,
@@ -240,7 +241,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         return result
 
-    def _getExpandedEOCs(self, obj, **args):
+    def _generateExpandedEOCs(self, obj, **args):
         """Returns the expanded embedded object characters for an object."""
         result = []
         text = self._script.expandEOCs(obj)
@@ -248,7 +249,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             result.append(text)
         return result
 
-    def _getNumberOfChildren(self, obj, **args):
+    def _generateNumberOfChildren(self, obj, **args):
         result = []
         role = args.get('role', obj.getRole())
         if role == pyatspi.ROLE_LIST:
@@ -258,11 +259,12 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                                    "List with %d items",
                                    obj.childCount) % obj.childCount)
         else:
-            result.extend(speech_generator.SpeechGenerator._getNumberOfChildren(
-                self, obj, **args))
+            result.extend(
+                speech_generator.SpeechGenerator._generateNumberOfChildren(
+                    self, obj, **args))
         return result
 
-    def _getFocusedItem(self, obj, **args):
+    def _generateFocusedItem(self, obj, **args):
         result = []
         role = args.get('role', obj.getRole())
         if role == pyatspi.ROLE_LIST:
@@ -274,12 +276,12 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                     break
             item = item or obj[0]
             if item:
-                name = self._getName(item, **args)
-                if name and name != self._getLabel(obj, **args):
+                name = self._generateName(item, **args)
+                if name and name != self._generateLabel(obj, **args):
                     result.extend(name)
         return result
 
-    def _getAncestors(self, obj, **args):
+    def _generateAncestors(self, obj, **args):
         result = []
         priorObj = args.get('priorObj', None)
         commonAncestor = self._script.findCommonAncestor(priorObj, obj)
@@ -374,7 +376,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             # has this state, but in the case of a group of radio buttons,
             # it is the group which has the state).
             #
-            result.extend(self._getRequired(parent, **args))
+            result.extend(self._generateRequired(parent, **args))
 
             result.extend(newResult)
 
@@ -384,11 +386,12 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
         return result
 
-    def getSpeech(self, obj, **args):
+    def generateSpeech(self, obj, **args):
         # ARIA widgets get treated like regular default widgets.
         #
         result = []
         args['isAria'] = self._script.isAriaWidget(obj)
-        result = speech_generator.SpeechGenerator.getSpeech(self, obj, **args)
+        result = speech_generator.SpeechGenerator.generateSpeech(
+                     self, obj, **args)
         del args['isAria']
         return result
diff --git a/src/orca/scripts/toolkits/J2SE-access-bridge/speech_generator.py b/src/orca/scripts/toolkits/J2SE-access-bridge/speech_generator.py
index e72f2f4..19a78a7 100644
--- a/src/orca/scripts/toolkits/J2SE-access-bridge/speech_generator.py
+++ b/src/orca/scripts/toolkits/J2SE-access-bridge/speech_generator.py
@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2006-2009 Sun Microsystems Inc.
+# Copyright 2005-2009 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -38,14 +38,14 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
     def __init__(self, script):
         speech_generator.SpeechGenerator.__init__(self, script)
 
-    def _getAncestors(self, obj, **args):
+    def _generateAncestors(self, obj, **args):
         """The Swing toolkit has labelled panels that do not implement the
         AccessibleText interface, but getDisplayedText returns a
         meaningful string that needs to be used if getDisplayedLabel
         returns None.
         """
         args['requireText'] = False
-        result = speech_generator.SpeechGenerator._getAncestors(
+        result = speech_generator.SpeechGenerator._generateAncestors(
             self, obj, **args)
         del args['requireText']
         return result
diff --git a/src/orca/speech_generator.py b/src/orca/speech_generator.py
index 529e606..d0a2a75 100644
--- a/src/orca/speech_generator.py
+++ b/src/orca/speech_generator.py
@@ -52,14 +52,14 @@ def _formatExceptionInfo(maxTBlevel=5):
     excTb = traceback.format_tb(trbk, maxTBlevel)
     return (excName, excArgs, excTb)
 
-# [[[WDW - general note -- for all the _get* methods, it would be great if
+# [[[WDW - general note -- for all the _generate* methods, it would be great if
 # we could return an empty array if we can determine the method does not
 # apply to the object.  This would allow us to reduce the number of strings
 # needed in formatting.py.]]]
 
 class SpeechGenerator:
     """Takes accessible objects and produces a string to speak for
-    those objects.  See the getSpeech method, which is the primary
+    those objects.  See the generateSpeech method, which is the primary
     entry point.  Subclasses can feel free to override/extend the
     speechGenerators instance field as they see fit."""
 
@@ -88,11 +88,12 @@ class SpeechGenerator:
     def __init__(self, script):
         self._script = script
         self._methodsDict = {}
+        METHOD_PREFIX = "_generate"
         for method in \
             filter(lambda z: callable(z),
                    map(lambda y: getattr(self, y).__get__(self, self.__class__),
-                       filter(lambda x: x.startswith("_get"), dir(self)))):
-            name = method.__name__[4:]
+                       filter(lambda x: x.startswith(METHOD_PREFIX), dir(self)))):
+            name = method.__name__[len(METHOD_PREFIX):]
             name = name[0].lower() + name[1:]
             self._methodsDict[name] = method
 
@@ -156,7 +157,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getName(self, obj, **args):
+    def _generateName(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the name of the object.  If the
         object is directly displaying any text, that text will be
@@ -164,11 +165,11 @@ class SpeechGenerator:
         object will be used.  If there is no accessible name, then the
         description of the object will be used.  This method will
         return an empty array if nothing can be found.  [[[WDW - I
-        wonder if we should just have _getName, _getDescription,
-        _getDisplayedText, etc., that don't do any fallback.  Then, we
+        wonder if we should just have _generateName, _generateDescription,
+        _generateDisplayedText, etc., that don't do any fallback.  Then, we
         can allow the formatting to do the fallback (e.g.,
         'displayedText or name or description'). [[[JD to WDW - I needed
-        a _getDescription for whereAmI. :-) See below.
+        a _generateDescription for whereAmI. :-) See below.
         """
         result = []
         name = self._script.getDisplayedText(obj)
@@ -178,7 +179,7 @@ class SpeechGenerator:
             result.append(obj.description)
         return result
 
-    def _getDescription(self, obj, **args):
+    def _generateDescription(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the description of the object,
         if that description is different from that of the name and
@@ -190,7 +191,7 @@ class SpeechGenerator:
             result.append(obj.description)
         return result
 
-    def _getTextRole(self, obj, **args):
+    def _generateTextRole(self, obj, **args):
         """A convenience method to prevent the pyatspi.ROLE_PARAGRAPH role
         from being spoken. In the case of a pyatspi.ROLE_PARAGRAPH
         role, an empty array will be returned. In all other cases, the
@@ -198,17 +199,17 @@ class SpeechGenerator:
         possibly voice and audio specifications).  Note that a 'role'
         attribute in args will override the accessible role of the
         obj. [[[WDW - I wonder if this should be moved to
-        _getRoleName.  Or, maybe make a 'do not speak roles' attribute
+        _generateRoleName.  Or, maybe make a 'do not speak roles' attribute
         of a speech generator that we can update and the user can
         override.]]]
         """
         result = []
         role = args.get('role', obj.getRole())
         if role != pyatspi.ROLE_PARAGRAPH:
-            result.extend(self._getRoleName(obj, **args))
+            result.extend(self._generateRoleName(obj, **args))
         return result
 
-    def _getRoleName(self, obj, **args):
+    def _generateRoleName(self, obj, **args):
         """Returns the role name for the object in an array of strings (and
         possibly voice and audio specifications), with the exception
         that the pyatspi.ROLE_UNKNOWN role will yield an empty array.
@@ -229,9 +230,9 @@ class SpeechGenerator:
         accessible role of the obj.  This is provided mostly as a
         method for scripts to call.
         """
-        return self._getRoleName(obj, **args)
+        return self._generateRoleName(obj, **args)
 
-    def _getLabel(self, obj, **args):
+    def _generateLabel(self, obj, **args):
         """Returns the label for an object as an array of strings (and
         possibly voice and audio specifications).  The label is
         determined by the getDisplayedLabel of the script, and an
@@ -243,14 +244,14 @@ class SpeechGenerator:
             result = [label]
         return result
 
-    def _getLabelAndName(self, obj, **args):
+    def _generateLabelAndName(self, obj, **args):
         """Returns the label and the name as an array of strings (and possibly
         voice and audio specifications).  The name will only be
         present if the name is different from the label.
         """
         result = []
-        label = self._getLabel(obj, **args)
-        name = self._getName(obj, **args)
+        label = self._generateLabel(obj, **args)
+        name = self._generateName(obj, **args)
         result.extend(label)
         if not len(label):
             result.extend(name)
@@ -258,20 +259,20 @@ class SpeechGenerator:
             result.extend(name)
         return result
 
-    def _getLabelOrName(self, obj, **args):
+    def _generateLabelOrName(self, obj, **args):
         """Returns the label as an array of strings (and possibly voice
         specifications).  If the label cannot be found, the name will
         be used instead.  If the name cannot be found, an empty array
         will be returned.
         """
         result = []
-        result.extend(self._getLabel(obj, **args))
+        result.extend(self._generateLabel(obj, **args))
         if not result:
             if obj.name and (len(obj.name)):
                 result.append(obj.name)
         return result
 
-    def _getUnrelatedLabels(self, obj, **args):
+    def _generateUnrelatedLabels(self, obj, **args):
         """Returns, as an array of strings (and possibly voice
         specifications), all the labels which are underneath the obj's
         hierarchy and which are not in a label for or labelled by
@@ -280,17 +281,17 @@ class SpeechGenerator:
         labels = self._script.findUnrelatedLabels(obj)
         result = []
         for label in labels:
-            name = self._getName(label, **args)
+            name = self._generateName(label, **args)
             result.extend(name)
         return result
 
-    def _getEmbedded(self, obj, **args):
+    def _generateEmbedded(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) used especially for handling embedded objects.
         This either is the label or name of the object or the name of
         the application for the object.
         """
-        result = self._getLabelOrName(obj, **args)
+        result = self._generateLabelOrName(obj, **args)
         if not result:
             try:
                 result.append(obj.getApplication().name)
@@ -304,7 +305,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getCheckedState(self, obj, **args):
+    def _generateCheckedState(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the checked state of the
         object.  This is typically for check boxes. [[[WDW - should we
@@ -328,13 +329,13 @@ class SpeechGenerator:
             result.append(_("not checked"))
         return result
 
-    def _getCellCheckedState(self, obj, **args):
+    def _generateCellCheckedState(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the checked state of the
         object.  This is typically for check boxes that are in a
         table. An empty array will be returned if this is not a
         checkable cell.  [[[WDW - I wonder if we can roll this into
-        _getCheckedState somehow.]]]
+        _generateCheckedState somehow.]]]
         """
         result = []
         try:
@@ -350,17 +351,17 @@ class SpeechGenerator:
                 if action.getName(i) in ["toggle", _("toggle")]:
                     oldRole = self._overrideRole(pyatspi.ROLE_CHECK_BOX,
                                             args)
-                    result.extend(self.getSpeech(obj, **args))
+                    result.extend(self.generateSpeech(obj, **args))
                     self._restoreRole(oldRole, args)
         return result
 
-    def _getRadioState(self, obj, **args):
+    def _generateRadioState(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the checked state of the
         object.  This is typically for check boxes. [[[WDW - should we
         return an empty array if we can guarantee we know this thing
         is not checkable?]]] [[[WDW - I wonder if we can roll this
-        into _getCheckedState somehow and provide some sort of
+        into _generateCheckedState somehow and provide some sort of
         settings.py string to let you specify the wording to be used
         for different roles.]]]
         """
@@ -378,13 +379,13 @@ class SpeechGenerator:
             result.append(C_("radiobutton", "not selected"))
         return result
 
-    def _getToggleState(self, obj, **args):
+    def _generateToggleState(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the checked state of the
         object.  This is typically for check boxes. [[[WDW - should we
         return an empty array if we can guarantee we know this thing
         is not checkable?]]] [[[WDW - I wonder if we can roll this
-        into _getCheckedState somehow and provide some sort of
+        into _generateCheckedState somehow and provide some sort of
         settings.py string to let you specify the wording to be used
         for different roles.]]]
         """
@@ -401,7 +402,7 @@ class SpeechGenerator:
             result.append(_("not pressed"))
         return result
 
-    def _getExpandableState(self, obj, **args):
+    def _generateExpandableState(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the expanded/collapsed state of
         an object, such as a tree node. If the object is not
@@ -425,7 +426,7 @@ class SpeechGenerator:
                 result.append(_("collapsed"))
         return result
 
-    def _getMultiselectableState(self, obj, **args):
+    def _generateMultiselectableState(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the multiselectable state of
         the object.  This is typically for check boxes. If the object
@@ -441,12 +442,12 @@ class SpeechGenerator:
             result.append(_("multi-select"))
         return result
 
-    def _getMenuItemCheckedState(self, obj, **args):
+    def _generateMenuItemCheckedState(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the checked state of the menu
         item, only if it is checked. Otherwise, and empty array will
         be returned.  [[[WDW - I wonder if we can roll this into
-        _getCheckedState somehow.]]]
+        _generateCheckedState somehow.]]]
         """
         result = []
         if obj.getState().contains(pyatspi.STATE_CHECKED):
@@ -455,7 +456,7 @@ class SpeechGenerator:
             result.append(_("checked"))
         return result
 
-    def _getAvailability(self, obj, **args):
+    def _generateAvailability(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the
         grayed/sensitivity/availability state of the object, but only
@@ -471,7 +472,7 @@ class SpeechGenerator:
             result.append(_("grayed"))
         return result
 
-    def _getRequired(self, obj, **args):
+    def _generateRequired(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the required state of the
         object, but only if it is required (i.e., it is in a dialog
@@ -485,7 +486,7 @@ class SpeechGenerator:
             result = [settings.speechRequiredStateString]
         return result
 
-    def _getReadOnly(self, obj, **args):
+    def _generateReadOnly(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the read only state of this
         object, but only if it is read only (i.e., it is a text area
@@ -503,7 +504,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getLinkInfo(self, obj, **args):
+    def _generateLinkInfo(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the protocol of the URI of
         the link associated with obj.
@@ -522,8 +523,8 @@ class SpeechGenerator:
             # Therefore, for now, I will hack in some code to do that
             # work here so that the before and after end results match.]]]
             #
-            result.extend(self._getLabel(obj))
-            result.extend(self._getRoleName(obj))
+            result.extend(self._generateLabel(obj))
+            result.extend(self._generateRoleName(obj))
             result.append(self._script.getDisplayedText(obj))
         else:
             link_uri_info = urlparse.urlparse(link_uri)
@@ -550,10 +551,10 @@ class SpeechGenerator:
                     linkOutput += " " + text
                 result.append(linkOutput)
                 if obj.childCount and obj[0].getRole() == pyatspi.ROLE_IMAGE:
-                    result.extend(self._getRoleName(obj[0]))
+                    result.extend(self._generateRoleName(obj[0]))
         return result
 
-    def _getSiteDescription(self, obj, **args):
+    def _generateSiteDescription(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that describe the site (same or different)
         pointed to by the URI of the link associated with obj.
@@ -600,7 +601,7 @@ class SpeechGenerator:
                     result.append(_('different site'))
         return result
 
-    def _getFileSize(self, obj, **args):
+    def _generateFileSize(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the size (Content-length) of
         the file pointed to by the URI of the link associated with
@@ -639,7 +640,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getImageDescription(self, obj, **args ):
+    def _generateImageDescription(self, obj, **args ):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the description of the image on
         the object, if it exists.  Otherwise, an empty array is
@@ -656,7 +657,7 @@ class SpeechGenerator:
                 result.append(description)
         return result
 
-    def _getImage(self, obj, **args):
+    def _generateImage(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the image on the the object, if
         it exists.  Otherwise, an empty array is returned.
@@ -668,7 +669,7 @@ class SpeechGenerator:
             pass
         else:
             role = pyatspi.ROLE_IMAGE
-            result.extend(self.getSpeech(obj, role=role))
+            result.extend(self.generateSpeech(obj, role=role))
         return result
 
     #####################################################################
@@ -677,7 +678,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getRowHeader(self, obj, **args):
+    def _generateRowHeader(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the row header for an object
         that is in a table, if it exists.  Otherwise, an empty array
@@ -720,7 +721,7 @@ class SpeechGenerator:
                     result.append(text)
         return result
 
-    def _getNewRowHeader(self, obj, **args):
+    def _generateNewRowHeader(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the row header for an object
         that is in a table, if it exists and if it is different from
@@ -763,10 +764,10 @@ class SpeechGenerator:
                        and (index != newRow) \
                        and ((newRow != oldRow) \
                             or (obj.parent != priorParent)):
-                        result = self._getRowHeader(obj, **args)
+                        result = self._generateRowHeader(obj, **args)
         return result
 
-    def _getColumnHeader(self, obj, **args):
+    def _generateColumnHeader(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the column header for an object
         that is in a table, if it exists.  Otherwise, an empty array
@@ -809,7 +810,7 @@ class SpeechGenerator:
                     result.append(text)
         return result
 
-    def _getNewColumnHeader(self, obj, **args):
+    def _generateNewColumnHeader(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the column header for an object
         that is in a table, if it exists and if it is different from
@@ -852,10 +853,10 @@ class SpeechGenerator:
                        and (index != newCol) \
                        and ((newCol != oldCol) \
                             or (obj.parent != priorParent)):
-                        result = self._getColumnHeader(obj, **args)
+                        result = self._generateColumnHeader(obj, **args)
         return result
 
-    def _getTableCell2ChildLabel(self, obj, **args):
+    def _generateTableCell2ChildLabel(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) for the label of a toggle in a table cell that
         has a special 2 child pattern that we run into.  Otherwise, an
@@ -894,10 +895,10 @@ class SpeechGenerator:
             if cellOrder:
                 for i in cellOrder:
                     if not hasToggle[i]:
-                        result.extend(self.getSpeech(obj[i], **args))
+                        result.extend(self.generateSpeech(obj[i], **args))
         return result
 
-    def _getTableCell2ChildToggle(self, obj, **args):
+    def _generateTableCell2ChildToggle(self, obj, **args):
         """Returns an array of strings (and possinly voice and audio
         specifications) for the toggle value of a toggle in a table
         cell that has a special 2 child pattern that we run into.
@@ -937,10 +938,10 @@ class SpeechGenerator:
             if cellOrder:
                 for i in cellOrder:
                     if hasToggle[i]:
-                        result.extend(self.getSpeech(obj[i], **args))
+                        result.extend(self.generateSpeech(obj[i], **args))
         return result
 
-    def _getRealTableCell(self, obj, **args):
+    def _generateRealTableCell(self, obj, **args):
         """Orca has a feature to automatically read an entire row of a table
         as the user arrows up/down the roles.  This leads to complexity in
         the code.  This method is used to return an array of strings
@@ -951,7 +952,7 @@ class SpeechGenerator:
         """
         result = []
         oldRole = self._overrideRole('REAL_ROLE_TABLE_CELL', args)
-        result.extend(self.getSpeech(obj, **args))
+        result.extend(self.generateSpeech(obj, **args))
         self._restoreRole(oldRole, args)
         if not result and settings.speakBlankLines \
            and not args.get('readingRow', False):
@@ -961,7 +962,7 @@ class SpeechGenerator:
             result = [_("blank")]
         return result
 
-    def _getTableCellRow(self, obj, **args):
+    def _generateTableCellRow(self, obj, **args):
         """Orca has a feature to automatically read an entire row of a table
         as the user arrows up/down the roles.  This leads to complexity in
         the code.  This method is used to return an array of strings
@@ -1031,14 +1032,14 @@ class SpeechGenerator:
                                     accHeader = \
                                         parentTable.getColumnHeader(i)
                                     result.append(accHeader.name)
-                        result.extend(self._getRealTableCell(cell, **args))
+                        result.extend(self._generateRealTableCell(cell, **args))
             else:
-                result.extend(self._getRealTableCell(obj, **args))
+                result.extend(self._generateRealTableCell(obj, **args))
         else:
-            result.extend(self._getRealTableCell(obj, **args))
+            result.extend(self._generateRealTableCell(obj, **args))
         return result
 
-    def _getUnselectedCell(self, obj, **args):
+    def _generateUnselectedCell(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) if this is an icon within an layered pane or a
         table cell within a table or a tree table and the item is
@@ -1087,7 +1088,7 @@ class SpeechGenerator:
 
         return result
 
-    def _getColumnAndRow(self, obj, **args):
+    def _generateColumnAndRow(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) reflecting the position of the cell in terms
         of its column number, the total number of columns, its row,
@@ -1119,7 +1120,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getTerminal(self, obj, **args):
+    def _generateTerminal(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) used especially for handling terminal objects.
         This either is the name of the frame the terminal is in or the
@@ -1204,7 +1205,7 @@ class SpeechGenerator:
 
         return attribStr
 
-    def _getTextInformation(self, obj, **args):
+    def _generateTextInformation(self, obj, **args):
         """Returns an empty array, but sets up a 'textInformation' attribute
         in self._valueCache for other methods to use.  The information
         is either:
@@ -1255,10 +1256,10 @@ class SpeechGenerator:
 
         return []
 
-    def _getTextContent(self, obj, **args):
+    def _generateTextContent(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) containing the text content.  This requires
-        _getTextInformation to have been called prior to this method.
+        _generateTextInformation to have been called prior to this method.
         """
         try:
             text = obj.queryText()
@@ -1266,18 +1267,18 @@ class SpeechGenerator:
             return []
 
         if not self._valueCache.has_key('textInformation'):
-            self._getTextInformation(obj, **args)
+            self._generateTextInformation(obj, **args)
         [line, startOffset, endOffset, selected] = \
             self._valueCache['textInformation']
 
         return [line]
 
-    def _getTextContentWithAttributes(self, obj, **args):
+    def _generateTextContentWithAttributes(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) containing the text content, obtained from the
         'textInformation' value of self._valueCache, with character
         attribute information mixed in.  This requires
-        _getTextInformation to have been called prior to this method.
+        _generateTextInformation to have been called prior to this method.
         """
         try:
             text = obj.queryText()
@@ -1285,7 +1286,7 @@ class SpeechGenerator:
             return []
 
         if not self._valueCache.has_key('textInformation'):
-            self._getTextInformation(obj, **args)
+            self._generateTextInformation(obj, **args)
         [line, startOffset, endOffset, selected] = \
             self._valueCache['textInformation']
 
@@ -1316,7 +1317,7 @@ class SpeechGenerator:
 
         return [newLine]
 
-    def _getCurrentLineText(self, obj, **args ):
+    def _generateCurrentLineText(self, obj, **args ):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represents the current line of text, if
         this is a text object.  [[[WDW - consider returning an empty
@@ -1325,7 +1326,7 @@ class SpeechGenerator:
         [text, caretOffset, startOffset] = self._script.getTextLineAtCaret(obj)
         return [text]
 
-    def _getDisplayedText(self, obj, **args ):
+    def _generateDisplayedText(self, obj, **args ):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represents all the text being displayed
         by the object. [[[WDW - consider returning an empty array if
@@ -1333,7 +1334,7 @@ class SpeechGenerator:
         """
         return [self._script.getDisplayedText(obj)]
 
-    def _getAnyTextSelection(self, obj, **args):
+    def _generateAnyTextSelection(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that says if any of the text for the entire
         object is selected. [[[WDW - I wonder if this string should be
@@ -1342,7 +1343,7 @@ class SpeechGenerator:
         result = []
 
         if not self._valueCache.has_key('textInformation'):
-            self._getTextInformation(obj, **args)
+            self._generateTextInformation(obj, **args)
         [line, startOffset, endOffset, selected] = \
             self._valueCache['textInformation']
 
@@ -1354,7 +1355,7 @@ class SpeechGenerator:
             result.append(text)
         return result
 
-    def _getAllTextSelection(self, obj, **args):
+    def _generateAllTextSelection(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that says if all the text for the entire
         object is selected. [[[WDW - I wonder if this string should be
@@ -1383,7 +1384,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getNodeLevel(self, obj, **args):
+    def _generateNodeLevel(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represents the tree node level of the
         object, or an empty array if the object is not a tree
@@ -1399,7 +1400,7 @@ class SpeechGenerator:
             result.append(_("tree level %d") % (level + 1))
         return result
 
-    def _getNewNodeLevel(self, obj, **args):
+    def _generateNewNodeLevel(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represents the tree node level of the
         object, or an empty array if the object is not a tree node or
@@ -1410,7 +1411,7 @@ class SpeechGenerator:
         settings.py.]]]
         """
 
-        # [[[TODO: WDW - hate duplicating code from _getNodeLevel,
+        # [[[TODO: WDW - hate duplicating code from _generateNodeLevel,
         # but don't want to call it because it will make the same
         # self._script.getNodeLevel call again.]]]
         #
@@ -1430,7 +1431,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getValue(self, obj, **args):
+    def _generateValue(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represents the value of the object.  This
         is typically the numerical value, but may also be the text
@@ -1440,7 +1441,7 @@ class SpeechGenerator:
         """
         return [self._script.getTextForValue(obj)]
 
-    def _getPercentage(self, obj, **args ):
+    def _generatePercentage(self, obj, **args ):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represents the percentage value of the
         object.  This is typically for progress bars. [[[WDW - we
@@ -1468,7 +1469,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getRadioButtonGroup(self, obj, **args):
+    def _generateRadioButtonGroup(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represents the radio button group label
         for the object, or an empty array if the object has no such
@@ -1499,7 +1500,7 @@ class SpeechGenerator:
 
         return result
 
-    def _getNewRadioButtonGroup(self, obj, **args):
+    def _generateNewRadioButtonGroup(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represents the radio button group label
         of the object, or an empty array if the object has no such
@@ -1508,7 +1509,7 @@ class SpeechGenerator:
         'priorObj' is typically set by Orca to be the previous object
         with focus.
         """
-        # [[[TODO: WDW - hate duplicating code from _getRadioButtonGroup
+        # [[[TODO: WDW - hate duplicating code from _generateRadioButtonGroup
         # but don't want to call it because it will make the same
         # AT-SPI method calls.]]]
         #
@@ -1535,7 +1536,7 @@ class SpeechGenerator:
                 result.append(self._script.getDisplayedText(radioGroupLabel))
         return result
 
-    def _getRealActiveDescendantDisplayedText(self, obj, **args ):
+    def _generateRealActiveDescendantDisplayedText(self, obj, **args ):
         """Objects, such as tables and trees, can represent individual cells
         via a complicated nested hierarchy.  This method returns an
         array of strings (and possibly voice and audio specifications)
@@ -1549,7 +1550,7 @@ class SpeechGenerator:
             result = [text]
         return result
 
-    def _getNumberOfChildren(self, obj, **args):
+    def _generateNumberOfChildren(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represents the number of children the
         object has.  [[[WDW - can we always return an empty array if
@@ -1567,7 +1568,7 @@ class SpeechGenerator:
             result.append(itemString)
         return result
 
-    def _getNoShowingChildren(self, obj, **args):
+    def _generateNoShowingChildren(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that says if this object has no showing
         children (e.g., it's an empty table or list).  object has.
@@ -1589,7 +1590,7 @@ class SpeechGenerator:
             result.append(_("0 items"))
         return result
 
-    def _getNoChildren(self, obj, **args ):
+    def _generateNoChildren(self, obj, **args ):
         """Returns an array of strings (and possibly voice and audio
         specifications) that says if this object has no children at
         all (e.g., it's an empty table or list).  object has.  [[[WDW
@@ -1605,7 +1606,7 @@ class SpeechGenerator:
             result.append(_("0 items"))
         return result
 
-    def _getSelectedItemCount(self, obj, **args):
+    def _generateSelectedItemCount(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) indicating how many items are selected in this
         and the position of the current item. This object will be an icon
@@ -1645,7 +1646,7 @@ class SpeechGenerator:
         result.append(itemString)
         return result
 
-    def _getSelectedItems(self, obj, **args):
+    def _generateSelectedItems(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) containing the names of all the selected items.
         This object will be an icon panel or a layered pane.
@@ -1658,10 +1659,10 @@ class SpeechGenerator:
             obj = obj.parent
         for child in obj:
             if child.getState().contains(pyatspi.STATE_SELECTED):
-                result.extend(self._getLabelAndName(child))
+                result.extend(self._generateLabelAndName(child))
         return result
 
-    def _getUnfocusedDialogCount(self, obj,  **args):
+    def _generateUnfocusedDialogCount(self, obj,  **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that says how many unfocused alerts and
         dialogs are associated with the application for this object.
@@ -1684,7 +1685,7 @@ class SpeechGenerator:
                             alertAndDialogCount) % alertAndDialogCount)
         return result
 
-    def _getAncestors(self, obj, **args):
+    def _generateAncestors(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the text of the ancestors for
         the object.  This is typically used to present the context for
@@ -1720,14 +1721,14 @@ class SpeechGenerator:
                         #
                         if parent.getRole() not in [pyatspi.ROLE_TABLE_CELL,
                                                     pyatspi.ROLE_FILLER]:
-                            result.extend(self._getRoleName(parent))
+                            result.extend(self._generateRoleName(parent))
                         result.append(text)
                         if parent.getRole() == pyatspi.ROLE_TABLE_CELL:
-                            result.extend(self._getRoleName(parent))
+                            result.extend(self._generateRoleName(parent))
                 parent = parent.parent
         return result.reverse() or result
 
-    def _getNewAncestors(self, obj, **args):
+    def _generateNewAncestors(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the text of the ancestors for
         the object.  This is typically used to present the context for
@@ -1741,10 +1742,10 @@ class SpeechGenerator:
         """
         result = []
         if args.get('priorObj', None):
-            result = self._getAncestors(obj, **args)
+            result = self._generateAncestors(obj, **args)
         return result
 
-    def _getParentRoleName(self, obj, **args):
+    def _generateParentRoleName(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) containing the role name of the parent of obj.
         """
@@ -1757,9 +1758,9 @@ class SpeechGenerator:
             return [_("Icon panel")]
         elif obj.parent.getRole() == pyatspi.ROLE_TABLE_CELL:
             obj = obj.parent
-        return self._getRoleName(obj.parent)
+        return self._generateRoleName(obj.parent)
 
-    def _getToolbar(self, obj, **args):
+    def _generateToolbar(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) containing the name and role of the toolbar
         which contains obj.
@@ -1769,11 +1770,11 @@ class SpeechGenerator:
                                             [pyatspi.ROLE_TOOL_BAR],
                                             [pyatspi.ROLE_FRAME])
         if ancestor:
-            result.append(self._getLabelAndName(ancestor))
-            result.append(self._getRoleName(ancestor))
+            result.append(self._generateLabelAndName(ancestor))
+            result.append(self._generateRoleName(ancestor))
         return result
 
-    def _getPositionInGroup(self, obj, **args):
+    def _generatePositionInGroup(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the relative position of an
         object in a group.
@@ -1799,7 +1800,7 @@ class SpeechGenerator:
 
         return result
 
-    def _getPositionInList(self, obj, **args):
+    def _generatePositionInList(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the relative position of an
         object in a list.
@@ -1808,7 +1809,7 @@ class SpeechGenerator:
         position = -1
         index = 0
         total = 0
-        name = self._getName(obj)
+        name = self._generateName(obj)
         # TODO - JD: There might be a better way to do this (e.g. pass
         # roles in maybe?).
         #
@@ -1831,14 +1832,14 @@ class SpeechGenerator:
         childNodes = self._script.getChildNodes(obj)
         total = len(childNodes)
         for i in range(0, total):
-            childName = self._getName(childNodes[i])
+            childName = self._generateName(childNodes[i])
             if childName == name:
                 position = i+1
                 break
 
         if not total:
             for child in obj:
-                next = self._getName(child)
+                next = self._generateName(child)
                 state = child.getState()
                 if not next or next[0] in ["", "Empty", "separator"] \
                    or not state.contains(pyatspi.STATE_VISIBLE):
@@ -1857,7 +1858,7 @@ class SpeechGenerator:
 
         return result
 
-    def _getNestingLevel(self, obj, **args):
+    def _generateNestingLevel(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the nesting level of an object
         in a list.
@@ -1877,7 +1878,7 @@ class SpeechGenerator:
             result.append(_("Nesting level %d") % nestingLevel)
         return result
 
-    def _getDefaultButton(self, obj, **args):
+    def _generateDefaultButton(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the default button in a dialog.
         This method should initially be called with a top-level window.
@@ -1885,7 +1886,7 @@ class SpeechGenerator:
         result = []
         button = self._script.findDefaultButton(obj)
         if button and button.getState().contains(pyatspi.STATE_SENSITIVE):
-            name = self._getName(button)
+            name = self._generateName(button)
             if name:
                 # Translators: The "default" button in a dialog box is the
                 # button that gets activated when Enter is pressed anywhere
@@ -1894,7 +1895,7 @@ class SpeechGenerator:
                 result.append(_("Default button is %s") % name[0])
         return result
 
-    def getDefaultButton(self, obj, **args):
+    def generateDefaultButton(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the default button of the window
         containing the object.
@@ -1902,9 +1903,9 @@ class SpeechGenerator:
         # TODO/Question - JD to WDW: Do we want to add this to the
         # formatting strings? For now, I've not done that.
         #
-        return self._getDefaultButton(obj, **args)
+        return self._generateDefaultButton(obj, **args)
 
-    def _getStatusBar(self, obj, **args):
+    def _generateStatusBar(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the status bar of a window.
         This method should initially be called with a top-level window.
@@ -1912,15 +1913,15 @@ class SpeechGenerator:
         result = []
         statusBar = self._script.findStatusBar(obj)
         if statusBar:
-            name = self._getName(statusBar)
+            name = self._generateName(statusBar)
             if name:
                 result.extend(name)
             else:
                 for child in statusBar:
-                    result.extend(self._getName(child))
+                    result.extend(self._generateName(child))
         return result
 
-    def getStatusBar(self, obj, **args):
+    def generateStatusBar(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the status bar of the window
         containing the object.
@@ -1928,9 +1929,9 @@ class SpeechGenerator:
         # TODO/Question - JD to WDW: Do we want to add this to the
         # formatting strings? For now, I've not done that.
         #
-        return self._getStatusBar(obj, **args)
+        return self._generateStatusBar(obj, **args)
 
-    def getTitle(self, obj, **args):
+    def generateTitle(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the title of the window, obj.
         containing the object, along with information associated with
@@ -1942,9 +1943,9 @@ class SpeechGenerator:
         result = []
         frame, dialog = self._script.findFrameAndDialog(obj)
         if frame:
-            result.append(self._getLabelAndName(frame))
+            result.append(self._generateLabelAndName(frame))
         if dialog:
-            result.append(self._getLabelAndName(dialog))
+            result.append(self._generateLabelAndName(dialog))
         alertAndDialogCount = \
                     self._script.getUnfocusedAlertAndDialogCount(obj)
         if alertAndDialogCount > 0:
@@ -1962,7 +1963,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getAccelerator(self, obj, **args):
+    def _generateAccelerator(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the accelerator for the object,
         or an empty array if no accelerator can be found.
@@ -1977,7 +1978,7 @@ class SpeechGenerator:
             result.append(accelerator)
         return result
 
-    def _getMnemonic(self, obj, **args):
+    def _generateMnemonic(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the mnemonic for the object, or
         an empty array if no mnemonic can be found.
@@ -2003,7 +2004,7 @@ class SpeechGenerator:
     #                                                                   #
     #####################################################################
 
-    def _getTutorial(self, obj, **args):
+    def _generateTutorial(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the tutorial for the object.
         The tutorial will only be generated if the user has requested
@@ -2045,7 +2046,7 @@ class SpeechGenerator:
             voice = settings.voices[settings.DEFAULT_VOICE]
         return [voice]
 
-    def getSpeech(self, obj, **args):
+    def generateSpeech(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the complete speech for the
         object.  The speech to be generated depends highly upon the
@@ -2110,7 +2111,7 @@ class SpeechGenerator:
             else:
                 firstTimeCalled = False
 
-            debug.println(debug.LEVEL_ALL, "getSpeech for %s using '%s'" \
+            debug.println(debug.LEVEL_ALL, "generateSpeech for %s using '%s'" \
                           % (repr(args), format))
 
             assert(format)
@@ -2138,6 +2139,6 @@ class SpeechGenerator:
             result = []
 
         debug.println(debug.LEVEL_ALL,
-                      "getSpeech generated '%s'" % repr(result))
+                      "generateSpeech generated '%s'" % repr(result))
 
         return result
diff --git a/src/orca/structural_navigation.py b/src/orca/structural_navigation.py
index a175d25..dfa76bd 100644
--- a/src/orca/structural_navigation.py
+++ b/src/orca/structural_navigation.py
@@ -1775,7 +1775,7 @@ class StructuralNavigation:
         else:
             voice = None
 
-        utterances = self._script.speechGenerator.getSpeech(obj)
+        utterances = self._script.speechGenerator.generateSpeech(obj)
         speech.speak(utterances, voice)
 
     #########################################################################
diff --git a/src/orca/where_am_I.py b/src/orca/where_am_I.py
index b7136ed..be13d7f 100644
--- a/src/orca/where_am_I.py
+++ b/src/orca/where_am_I.py
@@ -382,8 +382,9 @@ class WhereAmI:
             formatType = 'basicWhereAmI'
         else:
             formatType = 'detailedWhereAmI'
-        return self._script.speechGenerator.getSpeech(obj,
-                                                      alreadyFocused=True,
-                                                      formatType=formatType,
-                                                      forceMnemonic=True,
-                                                      forceTutorial=True)
+        return self._script.speechGenerator.generateSpeech(
+                   obj,
+                   alreadyFocused=True,
+                   formatType=formatType,
+                   forceMnemonic=True,
+                   forceTutorial=True)



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/orca/scripts/apps/evolution/speech_generator.py b/src/orca/scripts/apps/evolution/speech_generator.py
index 0d71bee..fce1b07 100644
--- a/src/orca/scripts/apps/evolution/speech_generator.py
+++ b/src/orca/scripts/apps/evolution/speech_generator.py
@@ -30,8 +30,8 @@ import pyatspi
 import orca.speech_generator as speech_generator
 
 class SpeechGenerator(speech_generator.SpeechGenerator):
-    """Overrides _getSpeechForTableCell so that, if this is an expanded
-       table cell,  we can strip off the "0 items".
+    """Overrides _generateSpeechForTableCell so that, if this is an
+       expanded table cell, we can strip off the "0 items".
     """
 
     # pylint: disable-msg=W0142
@@ -39,7 +39,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
     def __init__(self, script):
         speech_generator.SpeechGenerator.__init__(self, script)
 
-    def _getRealTableCell(self, obj, **args):
+    def _generateRealTableCell(self, obj, **args):
         # Check that we are in a table cell in the mail message header list.
         # If we are and this table cell has an expanded state, then
         # dont speak the number of items.
@@ -54,8 +54,8 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 if state.contains(pyatspi.STATE_EXPANDED):
                     oldRole = self._overrideRole(
                         'ALTERNATIVE_REAL_ROLE_TABLE_CELL', args)
-                    result = self.getSpeech(obj, **args)
+                    result = self.generateSpeech(obj, **args)
                     self._restoreRole(oldRole, args)
                     return result
-        return speech_generator.SpeechGenerator._getRealTableCell(
+        return speech_generator.SpeechGenerator._generateRealTableCell(
             self, obj, **args)
diff --git a/src/orca/scripts/apps/gcalctool/speech_generator.py b/src/orca/scripts/apps/gcalctool/speech_generator.py
index ea2fe5f..4b027c6 100644
--- a/src/orca/scripts/apps/gcalctool/speech_generator.py
+++ b/src/orca/scripts/apps/gcalctool/speech_generator.py
@@ -22,27 +22,27 @@
 __id__        = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
-__copyright__ = "Copyright (c) 2005-2009 Sun Microsystems Inc."
+__copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import orca.speech_generator as speech_generator
 import pyatspi
 
 class SpeechGenerator(speech_generator.SpeechGenerator):
-    """Overrides _getSpeechForPushButton to handle 'unspeakable'
-    button labels displayed on the screen.
+    """Overrides _generateName to handle 'unspeakable' button labels
+    displayed on the screen.
     """
     def __init__(self, script):
         speech_generator.SpeechGenerator.__init__(self, script)
 
-    def _getName(self, obj, **args):
+    def _generateName(self, obj, **args):
         """Gives preference to the object name versus what is being
         displayed on the screen.  This helps accomodate the naming
         hints being given to us by gcalctool for it's mathematical
         operator buttons."""
 
         if obj.getRole() != pyatspi.ROLE_PUSH_BUTTON:
-            return speech_generator.SpeechGenerator._getName(\
+            return speech_generator.SpeechGenerator._generateName(\
                 self, obj)
 
         if obj.name:
diff --git a/src/orca/scripts/apps/rhythmbox/speech_generator.py b/src/orca/scripts/apps/rhythmbox/speech_generator.py
index 5279aa6..aaf3104 100644
--- a/src/orca/scripts/apps/rhythmbox/speech_generator.py
+++ b/src/orca/scripts/apps/rhythmbox/speech_generator.py
@@ -31,18 +31,18 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
 
     # pylint: disable-msg=W0142
 
     """Overrides _getRealTableCell to correctly handle the table
     cells in the Library table.
     """
     def __init__(self, script):
         speech_generator.SpeechGenerator.__init__(self, script)
 
-    def _getRealTableCell(self, obj, **args):
+    def _generateRealTableCell(self, obj, **args):
         # Check to see if this is a table cell from the Library table.
         # If so, it'll have five children and we are interested in the
         # penultimate one. See bug #512639 for more details.
         #
         if obj.childCount == 5:
             obj = obj[3]
-        return speech_generator.SpeechGenerator._getRealTableCell(
+        return speech_generator.SpeechGenerator._generateRealTableCell(
             self, obj, **args)
@@ -31,18 +31,18 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
     # pylint: disable-msg=W0142
 
-    """Overrides _getRealTableCell to correctly handle the table
+    """Overrides _generateRealTableCell to correctly handle the table
     cells in the Library table.
     """
diff --git a/src/orca/scripts/apps/soffice/script.py b/src/orca/scripts/apps/soffice/script.py
index 8947888..c8f8800 100644
--- a/src/orca/scripts/apps/soffice/script.py
+++ b/src/orca/scripts/apps/soffice/script.py
@@ -781,7 +781,7 @@ class Script(default.Script):
             return (cell != None)
 
         self.updateBraille(cell)
-        utterances = self.speechGenerator.getSpeech(cell)
+        utterances = self.speechGenerator.generateSpeech(cell)
         # [[[TODO: WDW - need to make sure assumption about utterances[0]
         # is still correct with the new speech generator stuff.]]]
         #
@@ -1507,7 +1507,7 @@ class Script(default.Script):
         # box in Calc. If so, then replace the non-existent name with a
         # simple one before falling through and calling the default
         # locusOfFocusChanged method, which in turn will result in our
         # _getSpeechForComboBox() method being called.
         #
         rolesList = [pyatspi.ROLE_LIST,
                      pyatspi.ROLE_COMBO_BOX,
@@ -1539,7 +1539,8 @@ class Script(default.Script):
         if self.isSpreadSheetCell(event.source, True):
             if newLocusOfFocus:
                 self.updateBraille(newLocusOfFocus)
-                utterances = self.speechGenerator.getSpeech(newLocusOfFocus)
+                utterances = \
+                    self.speechGenerator.generateSpeech(newLocusOfFocus)
                 speech.speak(utterances)
 
                 # Save the current row and column information in the table
@@ -1576,7 +1577,8 @@ class Script(default.Script):
                     for tab in child:
                         eventState = tab.getState()
                         if eventState.contains(pyatspi.STATE_SELECTED):
-                            utterances = self.speechGenerator.getSpeech(tab)
+                            utterances = \
+                                self.speechGenerator.generateSpeech(tab)
                             speech.speak(utterances)
             # Fall-thru to process the event with the default handler.
 
@@ -1876,7 +1878,7 @@ class Script(default.Script):
                 weToggledIt = wasCommand and keyString not in navKeys
 
             if weToggledIt:
-                speech.speak(self.speechGenerator.getSpeech(event.source))
+                speech.speak(self.speechGenerator.generateSpeech(event.source))
 
         # When a new paragraph receives focus, we get a caret-moved event and
         # two focus events (the first being object:state-changed:focused).
@@ -1507,7 +1507,7 @@ class Script(default.Script):
         # simple one before falling through and calling the default
         # locusOfFocusChanged method, which in turn will result in our
-        # _getSpeechForComboBox() method being called.
+        # _generateSpeechForComboBox() method being called.
         #
         rolesList = [pyatspi.ROLE_LIST,